`include "define.vh"

module top(
    clk,       // 时钟信号
    data_a,
    rstn,      // 复位信号（低电平有效）
	overflow,  // 溢出标志
	nan,       // NaN标志
	zero,      // 零标志
    result     // 计算结果
);
//**********************************************************************
// --- Input/Output Declaration
//**********************************************************************
	localparam NUM_DATA = 32;
	input clk;
	input rstn;
	reg [31:0] mem_data_1 [0:NUM_DATA-1];
	output reg   [31:0] data_a;
    output wire   [31:0] result;
    output overflow,nan,zero;
    reg start;
    reg ce;
	reg [$clog2(NUM_DATA+1):0] i_data;
	
//**********************************************************************
// --- Main core
//**********************************************************************	
	FP_Sqrt_Top FP_Sqrt(
		.clk		(clk),       // 时钟信号
		.rstn		(rstn),      // 复位信号（低电平有效）
		`ifdef CE
		.ce			(1'b1),        // 时钟使能信号
		`endif
		.data_a		(data_a),    // 输入数据A
		`ifdef NAN
		.nan		(nan),       // NaN标志
		`endif
		`ifdef ZERO
		.zero		(zero),      // 零标志
		`endif
		`ifdef OVERFLOW
		.overflow	(overflow), //除零
		`endif 
		.result		(result)     // 计算结果
	);
	
	always @(posedge clk or negedge rstn) begin
		if(!rstn) begin
			i_data <= 0;
		end
		else if(start) begin
			i_data <= i_data + 1'b1;
		end
	end
	
	always @(posedge clk or negedge rstn) begin
		if(!rstn) begin
			data_a <= 0;
		end
		else if(start) begin
			data_a <= mem_data_1[i_data];
		end
	end
	
    always @(posedge clk) begin

        if(!rstn) begin
            start <= 0;
            
        end else begin
            start <= 1;
        end
    end

    always @(posedge clk or negedge rstn) begin

        if(!rstn) begin
            ce <= 0;
            
        end else if(i_data ==  5) begin
            ce <= 1;
        end
    end

	initial begin
		$readmemh("../proj/src/data/x.dat",mem_data_1);
	end

endmodule
